@@ -6,15 +6,13 @@
 #' @param n \code{\link{integer}}: The number of activity instances to select.
 #'
 #' @export
-first_n <- function(log, n, eventlog = deprecated()) {
+first_n <- function(log, n) {
 	UseMethod("first_n")
 }
 
 #' @describeIn first_n Select first n activity instances of an \code{\link{eventlog}}.
 #' @export
-first_n.eventlog <- function(log, n, eventlog = deprecated()) {
-
-	log <- lifecycle_warning_eventlog(log, eventlog)
+first_n.eventlog <- function(log, n) {
 
 	log %>%
 		arrange(.data[[timestamp(log)]], .data[[".order"]]) %>%
@@ -23,9 +21,7 @@ first_n.eventlog <- function(log, n, eventlog = deprecated()) {
 
 #' @describeIn first_n Select first n activity instances of an \code{\link{activitylog}}.
 #' @export
-first_n.activitylog <- function(log, n, eventlog = deprecated()) {
-
-	log <- lifecycle_warning_eventlog(log, eventlog)
+first_n.activitylog <- function(log, n) {
 
 	log %>%
 		rowwise() %>%
@@ -38,9 +34,7 @@ first_n.activitylog <- function(log, n, eventlog = deprecated()) {
 
 #' @describeIn first_n Select first n activity instances of a \code{\link{grouped_log}}.
 #' @export
-first_n.grouped_log <- function(log, n, eventlog = deprecated()) {
-
-	log <- lifecycle_warning_eventlog(log, eventlog)
+first_n.grouped_log <- function(log, n) {
 
 	log %>%
 		apply_grouped_fun(first_n, n, .keep_groups = TRUE, .returns_log = TRUE)
