@@ -8,13 +8,12 @@
 #'
 #' @export
 #'
-set_resource_id <- function(log, resource_id, eventlog = deprecated()) {
+set_resource_id <- function(log, resource_id) {
 	UseMethod("set_resource_id")
 }
 #'
 #' @describeIn set_resource_id Set resource id
 #' @export
-set_resource_id.default <- function(log, resource_id, eventlog = deprecated()) {
-	log <- lifecycle_warning_eventlog(log, eventlog)
+set_resource_id.default <- function(log, resource_id) {
 	set_id(log, "resource_id", resource_id)
 }
