@@ -8,13 +8,12 @@
 #'
 #' @export
 #'
-set_timestamp <- function(log, timestamp, eventlog = deprecated()) {
+set_timestamp <- function(log, timestamp) {
 	UseMethod("set_timestamp")
 }
 #'
 #' @describeIn set_timestamp Set timestamp of eventlog
 #' @export
-set_timestamp.eventlog <- function(log, timestamp, eventlog = deprecated()) {
-	log <- lifecycle_warning_eventlog(log, eventlog)
+set_timestamp.eventlog <- function(log, timestamp) {
 	set_id(log, "timestamp", timestamp)
 }
